//+------------------------------------------------------------------+
//|                                       HTI Hybrid Trend Index.mq4 |
//|                                                       Steve Hogg |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+
#property copyright "Steve Hogg"
#property link      "http://www.metaquotes.net"

#property indicator_separate_window
#property indicator_minimum -100
#property indicator_maximum 100
#property indicator_buffers 2
#property indicator_color1 Yellow
#property indicator_color2 Red


//---- input parameters
//Periods used by the weighted indicators
extern int       KeyIndexPeriod=14; 

//Signal Period of the HTI. 
//Increase the number to lessen signals and smooth out the signal line
//Decrease the number to increase signals
extern int       SignalPeriod=5; 

//0 - Simple Moving Average
//1 - EMA
//2 - SMA
//3 - LWMA
extern int       SignalMethod=1;

//Weight is the factor used to determine how much a single indicator effects the HTI
//Increase the weight of one and it will be more of a factor
//Decrease the weight and it will be less of a factor
//Only integers, whole numbers, can be used
//If fractions are desired, increase the weights to tens  Ex 10,12,18 etc.
extern int       Weight_RSI=1; 
extern int       Weight_CCI=1;  
extern int       Weight_DeMarker=1;
extern int       Weight_Stochastic=1;
extern int       Weight_WPR=1; //Williams Percent Range
extern int       Weight_MFI=1; //Money Flow Index
extern double    CCI_Factor=3.5; //since CCI can go up or above 300, what factor will bring it down to a 100 figure



//---- buffers
double HTI_Buffer[];
double RSI_Buffer[];
double CCI_Buffer[];
double DeM_Buffer[];
double Sto_Buffer[];
double WpR_Buffer[];
double MFI_Buffer[];
double SignalBuffer[];


//---- variables
int SumWeight;
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
   IndicatorBuffers(8);

   SetIndexStyle(0,DRAW_LINE);
   SetIndexBuffer(0,HTI_Buffer);
   
   SetIndexStyle(1,DRAW_LINE);
   SetIndexBuffer(1,SignalBuffer);   
   
   SetIndexBuffer(2,RSI_Buffer);
   SetIndexBuffer(3,CCI_Buffer);
   SetIndexBuffer(4,DeM_Buffer);
   SetIndexBuffer(5,Sto_Buffer);
   SetIndexBuffer(6,WpR_Buffer);
   SetIndexBuffer(7,MFI_Buffer);
   

   IndicatorShortName("HTI"+"("+KeyIndexPeriod+","+SignalPeriod+")");
   SetIndexLabel(0,"HTI");

   SumWeight=Weight_RSI+Weight_CCI+Weight_DeMarker+Weight_Stochastic+Weight_WPR+Weight_MFI;
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
   int limit;

   int counted_bars = IndicatorCounted();
   //---- check for possible errors
   if (counted_bars<0) return(-1);
   //---- last counted bar will be recounted
   if (counted_bars>0) counted_bars--;
   limit = Bars - counted_bars;

   for(int i=limit; i>=0; i--)
   {
      RSI_Buffer[i] = (iRSI(NULL,0,KeyIndexPeriod,PRICE_TYPICAL,i)*2-100)*Weight_RSI;
      CCI_Buffer[i] = (iCCI(NULL,0,KeyIndexPeriod,PRICE_TYPICAL,i)/CCI_Factor)*Weight_CCI;
      DeM_Buffer[i] = ((iDeMarker(NULL,0,KeyIndexPeriod,i)*100)*2-100)*Weight_DeMarker;
      Sto_Buffer[i] = (iStochastic(NULL,0,5,3,3,MODE_SMA,0,MODE_MAIN,i)*2-100)*Weight_Stochastic;
      WpR_Buffer[i] = (iWPR(NULL,0,KeyIndexPeriod,i)*2+100)*Weight_WPR;
      MFI_Buffer[i] = (iMFI(NULL,0,KeyIndexPeriod,i)*2-100)*Weight_MFI;
      
      HTI_Buffer[i] = (RSI_Buffer[i]+CCI_Buffer[i]+DeM_Buffer[i]+Sto_Buffer[i]+WpR_Buffer[i]+MFI_Buffer[i])/SumWeight;  

    }
   for(i=limit; i>=0; i--)
    {
      SignalBuffer[i]=iMAOnArray(HTI_Buffer,0,SignalPeriod,0,SignalMethod,i);
    }
    
   //----
   return(0);
}
//+------------------------------------------------------------------+